Back

Confirmation before 29.04.16 14:25

## Order details:

`

    ORDER CONFIRMATION
    ==================

    -------------------------------------
    Order ID : 3911831
    Your Order ID: Veloso01
    Customer ID  : 52826
    Orderer ID   : 52827
    -------------------------------------

    Fisher Scientific, Lda.

    Lagoas Park, Edificio 11 - Piso 0
    PT-2740-270 Porto Salvo

    CUSTOMER ADDRESS:
    -----------------
    Fisher Scientific, Lda.

    Lagoas Park, Edificio 11 - Piso 0
    PT-2740-270 Porto Salvo

    SHIPPING ADDRESS:
    -----------------
    Mr. Flávio de Azevedo
    University of Minho
    Biology
    Department of Biology
    Campus de Gualtar
    PT-4710-057 Braga

    Phone:   Fax:
    Email: bjorn_johansson@bio.uminho.pt
    VAT (customer):
    VAT (orderer):

    Order Date:      29.04.16 14:25
    Order Submitted: 27.04.16 16:51
    Shipment:  - EXPRESS SHIPPING -
    Payment Method:  - EVO-Card 00008270 -

    Order Comment:
    Bill Comment:

    oligo name.......... oligo details ......................................... price
    =====================================================================================
    Amp.fw               Unmodified DNA Oligos                                13.92 EUR
                         5'-GAAAAGCGTTTACCTCGGAACTCTATTGTAAACCCTGATAAATGCT
                         TC-3'  Salt Free 0.01

    Pbr.fw               Unmodified DNA Oligos                                13.34 EUR
                         5'-AATCCAATCAGCGTAAGGTGTAGACTTTCTCTCGTTTCATCGGTAT
                         -3'  Salt Free 0.01

    Pbr.rev              Unmodified DNA Oligos                                14.21 EUR
                         5'-GTTGACTACTATTTACGCAGCAGATACGATCTGTCAGACCAAGTTT
                         ACT-3'  Salt Free 0.01

    Micron.fw            Unmodified DNA Oligos                                14.21 EUR
                         5'-ATCGTATCTGCTGCGTAAATAGTAGTCAACGATCGTACTTGTTACC
                         CAT-3'  Salt Free 0.01

    Micron.rev           Unmodified DNA Oligos                                13.92 EUR
                         5'-CAGAGCAGACAGTTCCTTTACGAGATTTTAGATCCAATATCAAAGG
                         AA-3'  Salt Free 0.01

    dleu2.rev            Unmodified DNA Oligos                                13.34 EUR
                         5'-ACGGACTACGAGATACCTGATTTTACAGTTTAAGGCCGTTTCTGAC
                         -3'  Salt Free 0.01

    crp.fw               Unmodified DNA Oligos                                13.34 EUR
                         5'-AACTGTAAAATCAGGTATCTCGTAGTCCGTGTTCTGATCCTCGAGC
                         -3'  Salt Free 0.01

    crp.rev              Unmodified DNA Oligos                                13.63 EUR
                         5'-TACAATAGAGTTCCGAGGTAAACGCTTTTCGTTCTTGTCTCATTGC
                         C-3'  Salt Free 0.01

    leu2.fw              Unmodified DNA Oligos                                13.92 EUR
                         5'-TAAAATCTCGTAAAGGAACTGTCTGCTCTGTTAACTGTGGGAATAC
                         TC-3'  Salt Free 0.01

                         Printed Synth. Report                                 0.00 EUR
    =====================================================================================
                                                                               123.83 EUR

    All prices are net prices and do not include delivery costs and taxes.
    Country specific shipping charges can be found on our international shipping price list in the "Service Corner" menu.
    The stated prices are subject to change. Prices marked with * do not consider customer specific conditions and may vary for export countries.

` `

`